@@ -5,7 +5,7 @@ from config import CONFIG as cfg
 def participate(experiment, alternatives, client_id,
     force=None,
     traffic_fraction=None,
-    alternative=None,
+    prefetch=False,
     datetime=None,
     redis=None):
 
@@ -20,7 +20,7 @@ def participate(experiment, alternatives, client_id,
         alt = exp.winner
     else:
         client = Client(client_id, redis=redis)
-        alt = exp.get_alternative(client, alternative=alternative, dt=datetime)
+        alt = exp.get_alternative(client, dt=datetime, prefetch=prefetch)
 
     return alt
 
