@@ -1,4 +1,5 @@
 from datetime import datetime
+from hashlib import sha1
 from math import log
 import operator
 import random
@@ -10,7 +11,6 @@ from db import _key, msetbit, sequential_id, first_key_with_bit_set
 # This is pretty restrictive, but we can always relax it later.
 VALID_EXPERIMENT_ALTERNATIVE_RE = re.compile(r"^[a-z0-9][a-z0-9\-_]*$", re.I)
 VALID_KPI_RE = re.compile(r"^[a-z0-9][a-z0-9\-_]*$", re.I)
-RANDOM_SAMPLE = .2
 
 
 class Client(object):
@@ -32,7 +32,6 @@ class Experiment(object):
 
         self.name = name
         self.redis = redis
-        self.random_sample = RANDOM_SAMPLE
         self.alternatives = self.initialize_alternatives(alternatives)
         self.kpi = None
 
@@ -44,25 +43,31 @@ class Experiment(object):
     def __repr__(self):
         return '<Experiment: {0})>'.format(self.name)
 
-    def objectify_by_period(self, period):
+    def objectify_by_period(self, period, slim=False):
         objectified = {
             'name': self.name,
             'period': period,
             'alternatives': [],
             'created_at': self.created_at,
+            'traffic_fraction': self.traffic_fraction,
             'total_participants': self.total_participants(),
             'total_conversions': self.total_conversions(),
             'description': self.description,
             'has_winner': self.winner is not None,
+            'winner': self.winner.name if self.winner is not None else '',
             'is_archived': self.is_archived(),
             'kpis': list(self.kpis),
             'kpi': self.kpi
         }
 
         for alternative in self.alternatives:
-            objectified_alt = alternative.objectify_by_period(period)
+            objectified_alt = alternative.objectify_by_period(period, slim)
             objectified['alternatives'].append(objectified_alt)
 
+        if slim:
+            for key in ['period', 'kpi', 'kpis', 'has_winner']:
+                del(objectified[key])
+
         return objectified
 
     def initialize_alternatives(self, alternatives):
@@ -77,7 +82,7 @@ class Experiment(object):
         if self.is_new_record():
             pipe.sadd(_key('e'), self.name)
 
-        pipe.hset(self.key(), 'created_at', datetime.now())
+        pipe.hset(self.key(), 'created_at', datetime.now().strftime("%Y-%m-%d %H:%M"))
         pipe.hset(self.key(), 'traffic_fraction', self._traffic_fraction)
 
         # reverse here and use lpush to keep consistent with using lrange
@@ -92,7 +97,11 @@ class Experiment(object):
 
     @property
     def created_at(self):
-        return self.redis.hget(self.key(), 'created_at')
+        # Note: the split here is to correctly format legacy dates
+        try:
+            return self.redis.hget(self.key(), 'created_at').split('.')[0]
+        except (AttributeError) as e:
+            return None
 
     def get_alternative_names(self):
         return [alt.name for alt in self.alternatives]
@@ -139,7 +148,7 @@ class Experiment(object):
         if stat_range not in ['days', 'months', 'years']:
             raise ValueError("Unrecognized stat range: {0}".format(stat_range))
 
-        pipe = self.redis.pipe()
+        pipe = self.redis.pipeline()
 
         stats = {}
         search_key = _key("{0}:{1}:{2}".format(stat_type, exp_key, stat_range))
@@ -170,12 +179,14 @@ class Experiment(object):
             return None
 
     def reset(self):
-        self.delete()
-
         name = self.name
+        desc = self.description
         alts = self.get_alternative_names()
 
+        self.delete()
+
         experiment = Experiment(name, alts, redis=self.redis)
+        experiment.update_description(desc)
         experiment.save()
 
     def delete(self):
@@ -190,6 +201,11 @@ class Experiment(object):
         for key in keys:
             pipe.delete(key)
 
+        # Delete the KPIs as well
+        kpi_keys = self.redis.keys('*:{0}/*'.format(self.name))
+        for kpi_key in kpi_keys:
+            pipe.delete(kpi_key)
+
         pipe.execute()
 
     def archive(self):
@@ -277,23 +293,19 @@ class Experiment(object):
             self._sequential_ids[client.client_id] = id_
         return self._sequential_ids[client.client_id]
 
-    def get_alternative(self, client, alternative=None, dt=None):
+    def get_alternative(self, client, dt=None, prefetch=False):
         """Returns and records an alternative according to the following
         precedence:
           1. An existing alternative
-          2. A client-chosen alternative
-          3. A server-chosen alternative
+          2. A server-chosen alternative
         """
         if self.is_archived():
             return self.control
 
         chosen_alternative = self.existing_alternative(client)
         if not chosen_alternative:
-            if alternative:
-                chosen_alternative, participate = Alternative(alternative, self, redis=self.redis), True
-            else:
-                chosen_alternative, participate = self.choose_alternative(client)
-            if participate:
+            chosen_alternative, participate = self.choose_alternative(client)
+            if participate and not prefetch:
                 chosen_alternative.record_participation(client, dt=dt)
 
         return chosen_alternative
@@ -325,30 +337,22 @@ class Experiment(object):
             self.exclude_client(client)
             return self.control, False
 
-        if cfg.get('enable_whiplash') and random.random() >= self.random_sample:
-            return Alternative(self._whiplash(), self, redis=self.redis), True
+        return self._uniform_choice(client), True
 
-        return self._random_choice(), True
+    # Ported from https://github.com/facebook/planout/blob/master/planout/ops/random.py
+    def _uniform_choice(self, client):
+        idx = self._get_hash(client) % len(self.alternatives)
+        return self.alternatives[idx]
 
-    def _random_choice(self):
-        return random.choice(self.alternatives)
+    def _get_hash(self, client):
+        salty = "{0}.{1}".format(self.name, client.client_id)
 
-    def _whiplash(self):
-        stats = {}
-        for alternative in self.alternatives:
-            participant_count = alternative.participant_count()
-            completed_count = alternative.completed_count()
-            stats[alternative.name] = self._arm_guess(participant_count, completed_count)
-
-        return max(stats.iteritems(), key=operator.itemgetter(1))[0]
-
-    def _arm_guess(self, participant_count, completed_count):
-        fairness_score = 7
-
-        a = max([participant_count, 0])
-        b = max([participant_count - completed_count, 0])
-
-        return random.betavariate(a + fairness_score, b + fairness_score)
+        # We're going to take the first 7 bytes of the client UUID
+        # because of the largest integer values that can be represented safely
+        # with Sixpack client libraries
+        # More Info: https://github.com/seatgeek/sixpack/issues/132#issuecomment-54318218
+        hashed = sha1(salty).hexdigest()[:7]
+        return int(hashed, 16)
 
     def existing_conversion(self, client):
         alts = self.get_alternative_names()
@@ -394,14 +398,19 @@ class Experiment(object):
         if traffic_fraction is None:
             traffic_fraction = 1
 
+        check_fraction = False
         try:
             experiment = Experiment.find(experiment_name, redis=redis)
+            check_fraction = True
         except ValueError:
             experiment = cls(experiment_name, alternatives, redis=redis)
             # TODO: I want to revist this later
             experiment.set_traffic_fraction(traffic_fraction)
             experiment.save()
 
+        if check_fraction and experiment.traffic_fraction != traffic_fraction:
+            raise ValueError('do not change traffic fraction once a test has started. please delete in admin')
+
         # Make sure the alternative options are correct. If they are not,
         # raise an error.
         if sorted(experiment.get_alternative_names()) != sorted(alternatives):
@@ -456,7 +465,11 @@ class Alternative(object):
     def __repr__(self):
         return "<Alternative {0} (Experiment {1})>".format(repr(self.name), repr(self.experiment.name))
 
-    def objectify_by_period(self, period):
+    def objectify_by_period(self, period, slim=False):
+
+        if slim:
+            return self.name
+
         PERIOD_TO_METHOD_MAP = {
             'day': {
                 'participants': self.participants_by_day,
